BEGIN
                FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'ACCESS_REVIEW_SUMMARY_V') LOOP
                                EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM ACCESS_REVIEW_SUMMARY_V';
                END LOOP;
                FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'REVIEW_PARAMETER_V') LOOP
                                EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM REVIEW_PARAMETER_V';
                END LOOP;
                FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'ACCESS_REVIEW_SUMMARY_V') LOOP
                                EXECUTE IMMEDIATE 'DROP VIEW ACCESS_REVIEW_SUMMARY_V';
                END LOOP;
                FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'REVIEW_PARAMETER_V') LOOP
                                EXECUTE IMMEDIATE 'DROP VIEW REVIEW_PARAMETER_V';
                END LOOP;
END;
/

CREATE VIEW access_review_summary_v AS 
   SELECT 
  instance.id instance_id,
  defn.name,
  defn.description,
  defn.review_type,
  defn.next_schedule_date,
  defn.review_target_spec_json,
  multi_owner.review_owners review_inst_owner_display_name,
  instance.status,
  instance.status_comment,
  instance.start_date,
  instance.expected_end_date,
  instance.end_date,
  instance.valid_to_date,
  instance.canceled_by,
  instance.task_count,
  instance.task_complete_count,
  canceler.display_name canceled_by_name,
  instance.item_count,
  instances.reviewer_count,
 ( SELECT decisions.decision_count
         FROM ( SELECT inst.id  instance,
                  it.final_decision  decision,
                  COUNT(it.final_decision) decision_count
                 FROM review_instance inst
                   LEFT JOIN review_item it ON it.review_instance_id = inst.id
                GROUP BY inst.id, it.final_decision) decisions
        WHERE decisions.instance = instance.id AND decisions.decision = 'ASSIGN_USER')  assign_count,
  ( SELECT decisions.decision_count
         FROM ( SELECT inst.id AS instance,
                  it.final_decision decision,
                  COUNT(it.final_decision) AS decision_count
                 FROM review_instance inst
                   LEFT JOIN review_item it ON it.review_instance_id = inst.id
                GROUP BY inst.id, it.final_decision) decisions
        WHERE decisions.instance = instance.id AND decisions.decision = 'KEEP') AS keep_count,
  ( SELECT decisions.decision_count
         FROM ( SELECT inst.id AS instance,
                  it.final_decision decision,
                  COUNT(it.final_decision) decision_count
                 FROM review_instance inst
                   LEFT JOIN review_item it ON it.review_instance_id = inst.id
                GROUP BY inst.id, it.final_decision) decisions
        WHERE decisions.instance = instance.id AND decisions.decision = 'REMOVE')  remove_count 
 FROM review_instance instance
   JOIN review_definition defn ON instance.review_definition = defn.id
   JOIN ( SELECT inst.id AS instance,
          COUNT(DISTINCT rui.unique_user_id)  reviewer_count
         FROM review_instance inst
           LEFT JOIN reviewer_instance ri ON ri.review_instance_id = inst.id
           LEFT JOIN reviewer_user_instance rui ON rui.reviewer_instance_id = ri.id
        GROUP BY inst.id) instances ON instances.instance = instance.id
   LEFT JOIN suser canceler ON instance.canceled_by = canceler.unique_user_id AND canceler.effective=1
   LEFT JOIN reviewer_instance rev_owner ON instance.id = rev_owner.review_instance_id AND rev_owner.type = 'RO'
   LEFT JOIN suser review_owner ON rev_owner.single_reviewer_unique_id = review_owner.unique_user_id AND review_owner.effective = 1
   LEFT JOIN ( SELECT DISTINCT defn_1.name review_name,
               ri.id AS rid,
               LISTAGG((TO_CHAR(s.display_name)), ' | ') within GROUP (order by s.display_name) AS review_owners
               FROM review_instance ri
               JOIN review_definition defn_1 ON ri.review_definition = defn_1.id
               LEFT JOIN reviewer_instance rev_owner_1 ON ri.id = rev_owner_1.review_instance_id AND rev_owner_1.type = 'RO'
               LEFT JOIN reviewer_user_instance rui ON rui.reviewer_instance_id = rev_owner_1.id
               LEFT JOIN suser s ON rui.unique_user_id = s.unique_user_id AND s.effective=1
               GROUP BY defn_1.name, ri.id) multi_owner ON multi_owner.rid = instance.id
  WHERE defn.deleted = 0;

CREATE VIEW review_parameter_v AS 
  SELECT DISTINCT 
defn.name review_name,
defn.unique_review_def_id
FROM review_definition defn
where
    exists (select 1 from review_instance ri
    				 join review_item item on item.review_instance_id = ri.id
    				 where ri.review_definition = defn.id) AND defn.deleted = 0;

GRANT SELECT ON igops.access_review_summary_v TO igrptuser;
CREATE OR REPLACE PUBLIC SYNONYM access_review_summary_v for igops.access_review_summary_v;

GRANT SELECT ON igops.review_parameter_v TO igrptuser;
CREATE OR REPLACE PUBLIC SYNONYM review_parameter_v for igops.review_parameter_v;